# walnats

```{include} ../README.md
:start-after: "# walnats"
:end-before: "## Walnats in 30 seconds"
```

```{eval-rst}

.. toctree::
    :maxdepth: 1
    :caption: Basics

    intro
    events
    pub
    actors
    sub

.. toctree::
    :maxdepth: 1
    :caption: Dive deeper

    recipes
    clock
    resp
    middlewares
    decorators
    serializers
    services
    linter
    alloy

.. toctree::
    :maxdepth: 1
    :caption: References

    glossary
    integrations
    api
```
